@@ -2,7 +2,7 @@ library(shiny)
 library(shinyFiles)
 
 shinyServer(function(input, output, session) {
-    volumes <- getVolumes() #c('R Installation'=R.home())
+    volumes <- c('R Installation'=R.home())
     shinyFileChoose(input, 'file', roots=volumes, session=session, restrictions=system.file(package='base'))
     shinyDirChoose(input, 'directory', roots=volumes, session=session, restrictions=system.file(package='base'))
     shinyFileSave(input, 'save', roots=volumes, session=session, restrictions=system.file(package='base'))
